@@ -36,21 +36,7 @@ class Translatable(object):
     @hybrid_property
     def current_translation(self):
         locale = six.text_type(self._get_locale())
-        locale_obj = getattr(self, '_translation_%s' % locale)
-        if locale_obj:
-            return locale_obj
-
-        class_ = self.__translatable__['class']
-
-        obj = class_(translation_parent=self)
-
-        obj.locale = locale
-        setattr(
-            self,
-            '_translation_%s' % locale,
-            obj
-        )
-        return obj
+        return self.translations[locale]
 
     @current_translation.setter
     def current_translation(self, obj):
@@ -63,7 +49,7 @@ class Translatable(object):
         locale = six.text_type(six.get_unbound_function(cls.get_locale)(cls))
         return getattr(cls, '_translation_%s' % locale)
 
-    @property
+    @hybrid_property
     def translations(self):
         return TranslationsMapping(self)
 
@@ -77,11 +63,30 @@ class TranslationsMapping(object):
         return locale in self.manager.option(self.obj, 'locales')
 
     def format_key(self, locale):
-        return  '_translation_%s' % locale
+        return '_translation_%s' % locale
 
     def __getitem__(self, locale):
         if locale in self:
-            return getattr(self.obj, self.format_key(locale))
+            key = self.format_key(locale)
+            locale_obj = getattr(self.obj, key)
+            if locale_obj:
+                return locale_obj
+
+            class_ = self.obj.__translatable__['class']
+            locale_obj = class_(
+                translation_parent=self.obj,
+                locale=locale
+            )
+            setattr(self.obj, key, locale_obj)
+            return locale_obj
+
+    @property
+    def all(self):
+        return list(self.values())
+
+    def values(self):
+        for locale in self.manager.option(self.obj, 'locales'):
+            yield self[locale]
 
     def __setitem__(self, locale, obj):
         if locale in self:
@@ -96,3 +101,7 @@ class TranslationsMapping(object):
     def iteritems(self):
         for locale in self.manager.option(self.obj, 'locales'):
             yield locale, self[locale]
+
+    def __iter__(self):
+        for locale in self.manager.option(self.obj, 'locales'):
+            yield locale, self[locale]
